@@ -111,7 +111,7 @@ public:
 
   const bool onFace ; //  true if do int on face or edge with jump (VF or GD : Galerkin Discontinus)
   // in with case  add ... 
-  const int lnk; // size of the 4 next array
+  const int lnki,lnkj; // size of the 4 next array
   int *nik,*nikk;  //  number of df in element   k,kk for VF and GD methode 
   int *njk,*njkk;  //  number of df in element   k,kk  for VF and GD methode
 
@@ -121,7 +121,7 @@ public:
     
     :   lga(llga),a(new R[lga]),
         ni(nni),nj(nnj),n(0),m(0),mtype(t),data(datasize),
-        onFace(false),lnk(0),nik(0),nikk(0),njk(0),njkk(0) 
+        onFace(false),lnki(0),lnkj(0),nik(0),nikk(0),njk(0),njkk(0)
         {}
        
 
@@ -134,13 +134,28 @@ public:
     lga(llga),a(new R[lga]),
     ni(nni),nj(nni),n(0),m(0),mtype(t),data(datasize*(lk?2:1)) ,
        onFace(lk!=0),
-       lnk(lk),
+       lnki(lk),lnkj(lk),
        nik(lk? new int[lk*2]:0),
        nikk(nik+lk),
        njk(nik),
        njkk(nik+lk)
        { ffassert(lk>=0);}
- 
+
+    //  for discontinous Galerkine method
+    MatriceElementaire(int datasize,int llga,int *nni,int lki,int *nnj,int lkj,
+                       TypeOfMatriceElementaire t=Full
+                       )
+    :
+    lga(llga),a(new R[lga]),
+    ni(nni),nj(nnj),n(0),m(0),mtype(t),data(datasize*(lki+lkj?2:1)) ,
+    onFace(lki+lkj),
+    lnki(lki),lnkj(lkj),
+    nik(lki? new int[lki*2]:0),
+    nikk(nik+lki),
+    njk(lkj? new int[lkj*2]:0),
+    njkk(njk+lkj)
+    {  ffassert(lki>=0);}// non teste ??? .... F. hecht ...
+
   virtual ~MatriceElementaire() {
     if(ni != nj) 
       delete [] nj;
@@ -224,6 +239,17 @@ public:
     MatDataFES<FES>(UUh,UUh,fit,fie),
     MatriceElementaire<R>(UUh.esize(),llga,nni,lk,t)
   {}
+    
+    MatriceElementaireFES(const FESpace & UUh,const FESpace & VVh,int llga
+                          ,int *nnj,int lkj,int * nni,int lki,TypeOfMatriceElementaire t=Full,
+                          const QFElement & fit=*QFElement::Default,
+                          const QFBorderElement & fie =*QFBorderElement::Default)
+    
+    :
+    MatDataFES<FES>(UUh,VVh,fit,fie),
+    MatriceElementaire<R>(UUh.esize()+VVh.esize(),llga,nnj,lkj,nni,lki,t)
+    {}
+    
   ~MatriceElementaireFES() {}
   const LinearComb<pair<MGauche,MDroit>,C_F0> * bilinearform;
   
@@ -287,6 +313,15 @@ public:
 				  new int[VVh.MaximalNbOfDF()],this->Full,fit,fie),
      element(0),faceelement(0) {}
 
+    MatriceElementairePleine(const FESpace & UUh,const FESpace & VVh,bool VF,
+                             const QFElement & fit=*QFElement::Default,
+                             const QFBorderElement & fie =*QFBorderElement::Default)
+    :MatriceElementaireFES<R,FES>(UUh,VVh,
+                                  UUh.MaximalNbOfDF()*VVh.MaximalNbOfDF()*4,
+                                  new int[UUh.MaximalNbOfDF()*2],VF?UUh.MaximalNbOfDF()*2:0,
+                                  new int[VVh.MaximalNbOfDF()*2],VF?VVh.MaximalNbOfDF()*2:0,this->Full,fit,fie),
+    element(0),faceelement(0) {}
+
 }; 
 
 template <class R,class FES=FESpace> 
@@ -662,7 +697,7 @@ int ConjuguedGradient(const M & A,const P & C,const KN_<R> &b,KN_<R> &x,const in
    if (verbosity>50) 
      kprint=2;
    if (verbosity>99)  cout << A << endl;
-   throwassert(&x && &b && &A && &C);
+//   throwassert(&x && &b && &A && &C);
    typedef KN<R> Rn;
    int n=b.N();   
    throwassert(n==x.N());
