@@ -18,6 +18,6 @@ string StrVersionNumber(){
 //  buffer.precision(8);
 //  buffer<<VersionNumber();
   static char buffer[100];
-  sprintf(buffer," %9f (date Ven 11 jul 2014 21:27:24 CEST)",VersionNumber());
-  return buffer; //.str()+" (date Ven 11 jul 2014 21:27:24 CEST)" ;
+  sprintf(buffer," %9f (date Ven 22 mai 2015 13:48:50 CEST)",VersionNumber());
+  return buffer; //.str()+" (date Ven 22 mai 2015 13:48:50 CEST)" ;
 }
